==================
django-allauth-cas
==================

CAS support for django-allauth_.

Supports:

- Django 1.8-10 - Python 2.7, 3.4-5
- Django 1.11 - Python 2.7, 3.4-6


.. _django-allauth: https://www.intenct.nl/projects/django-allauth/
